@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for batch service client
 
@@ -10,10 +11,12 @@ Usage::
     client: BatchClient = boto3.client("batch")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_batch.paginator import (
     DescribeComputeEnvironmentsPaginator,
     DescribeJobDefinitionsPaginator,
@@ -259,3 +262,6 @@ class BatchClient:
         """
         [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Paginator.ListJobs)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
