@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for batch service client paginators.
 
@@ -22,10 +23,11 @@ Usage::
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_batch.type_defs import (
     DescribeComputeEnvironmentsResponseTypeDef,
     DescribeJobDefinitionsResponseTypeDef,
